infinite_grouped_list library
Classes
-
InfiniteGroupedList<
ItemType, GroupBy, GroupTitle> - A list of items that are grouped and infinite.
-
InfiniteGroupedListController<
ItemType, GroupBy, GroupTitle> - This is the controller for the InfiniteGroupedList.
- PaginationInfo
Enums
- SortOrder
- The sort order of the items inside the groups.